@@ -119,10 +119,6 @@ struct DxcIncludeHandlerWrapperVtbl {
     ) -> HRESULT,
     add_ref: extern "system" fn(*const com_rs::IUnknown) -> HRESULT,
     release: extern "system" fn(*const com_rs::IUnknown) -> HRESULT,
-    #[cfg(not(windows))]
-    complete_object_destructor: extern "system" fn(*const com_rs::IUnknown) -> HRESULT,
-    #[cfg(not(windows))]
-    deleting_destructor: extern "system" fn(*const com_rs::IUnknown) -> HRESULT,
     load_source: extern "system" fn(*mut com_rs::IUnknown, LPCWSTR, *mut *mut IDxcBlob) -> HRESULT,
 }
 
@@ -143,7 +139,11 @@ impl<'a, 'i> DxcIncludeHandlerWrapper<'a, 'i> {
         HRESULT(0) // dummy impl
     }
 
-    extern "system" fn dummy(_me: *const com_rs::IUnknown) -> HRESULT {
+    extern "system" fn add_ref(_me: *const com_rs::IUnknown) -> HRESULT {
+        HRESULT(0) // dummy impl
+    }
+
+    extern "system" fn release(_me: *const com_rs::IUnknown) -> HRESULT {
         HRESULT(0) // dummy impl
     }
 
@@ -230,12 +230,8 @@ impl DxcCompiler {
         if let Some(include_handler) = include_handler {
             let vtable = DxcIncludeHandlerWrapperVtbl {
                 query_interface: DxcIncludeHandlerWrapper::query_interface,
-                add_ref: DxcIncludeHandlerWrapper::dummy,
-                release: DxcIncludeHandlerWrapper::dummy,
-                #[cfg(not(windows))]
-                complete_object_destructor: DxcIncludeHandlerWrapper::dummy,
-                #[cfg(not(windows))]
-                deleting_destructor: DxcIncludeHandlerWrapper::dummy,
+                add_ref: DxcIncludeHandlerWrapper::add_ref,
+                release: DxcIncludeHandlerWrapper::release,
                 load_source: DxcIncludeHandlerWrapper::load_source,
             };
 
@@ -481,7 +477,7 @@ fn dxcompiler_lib_name() -> &'static Path {
 
 #[cfg(target_os = "macos")]
 fn dxcompiler_lib_name() -> &'static Path {
-    Path::new("./libdxcompiler.dynlib")
+    Path::new("./libdxcompiler.dylib")
 }
 
 impl Dxc {
@@ -492,7 +488,7 @@ impl Dxc {
             if lib_path.is_file() {
                 lib_path
             } else {
-                lib_path.join(&dxcompiler_lib_name())
+                lib_path.join(dxcompiler_lib_name())
             }
         } else {
             dxcompiler_lib_name().to_owned()
